#[non_exhaustive]pub enum Error {
BufferTooShort {
need: usize,
have: usize,
what: &'static str,
},
OutputBufferTooSmall {
need: usize,
have: usize,
},
InvalidMessageLength {
length: u16,
reason: &'static str,
},
TruncatedParameter {
ptype: u16,
need: usize,
have: usize,
},
FieldTooWide {
what: &'static str,
value: usize,
bits: u32,
},
}Expand description
A SimulCrypt parse / serialize error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BufferTooShort
Input shorter than required.
Fields
OutputBufferTooSmall
The output buffer passed to serialize_into was too small.
InvalidMessageLength
The message_length header field is inconsistent with the bytes that
follow it (TS 103 197 Table 1b: it counts the bytes immediately after
the message_length field — i.e. the sum of all parameter TLVs).
TruncatedParameter
A parameter TLV was truncated: its parameter_length ran past the end
of the message body.
Fields
FieldTooWide
A value did not fit in its wire width when serializing (e.g. a TLV value
longer than the 16-bit parameter_length, or a body longer than the
16-bit message_length).